@@ -9,5 +9,5 @@ test_that("download_database works", {
   expect_equal(test_db[1, 1], "Chicago Region")
   expect_equal(ncol(test_db), 9)
 
-  expect_warning(download_database(3))
+  expect_warning(t <- download_database(3), "Specified database is empty.")
 })
